(->field x)(->field k v)Make a Field record, optionally from a vector, a map, or a Field
Make a Field record, optionally from a vector, a map, or a Field
(->lines ps)Dump collection of Point records to lines
Dump collection of Point records to lines
(->point x)(->point measurement tags fields timestamp)Make a Point record
Make a Point record
(->tag x)(->tag k v)Make a Tag record, optionally from a vector, a map, or a Tag
Make a Tag record, optionally from a vector, a map, or a Tag
(->timestamp x)Make a Timestamp record, from a Long, a String, or a Timestamp
Make a Timestamp record, from a Long, a String, or a Timestamp
(create-db client)Create database defined in client
Create database defined in client
(create-db-user client username password)(create-db-user client username password permissions)Create new database user
Create new database user
(db-query client q & [results->maps?])Perform arbitrary query string
Perform arbitrary query string
(delete-db client)Delete database defined in client
Delete database defined in client
(grant-db-user-permissions client username permissions)Grant database user privileges
Grant database user privileges
(list-db-users client & [results->maps?])List database users
List database users
(list-dbs client)Returns list of database names
Returns list of database names
(list-user-permissions client username & [results->maps?])Show database user privileges
Show database user privileges
(make-client opts)Returns a map representing an HTTP client configuration.
Valid options: :host (default: "localhost") :scheme (default: "http://") :port (default: 8086) :username (default "root") :password (default "root") :db (default: "testdb") :version (default: "0.9") :post-opts (http post options, default: "nil") :get-opts (http get options, default: "nil")
Returns a map representing an HTTP client configuration. Valid options: :host (default: "localhost") :scheme (default: "http://") :port (default: 8086) :username (default "root") :password (default "root") :db (default: "testdb") :version (default: "0.9") :post-opts (http post options, default: "nil") :get-opts (http get options, default: "nil")
(ping client)Get database status. Returns ping time in ms
Get database status. Returns ping time in ms
(revoke-db-user-permissions client username permissions)Revoke database user privileges
Revoke database user privileges
(update-user-password client username password)Update database user password
Update database user password
(write-lines client lines)Write using raw line String
Write using raw line String
(write-point client point)Write Point record to database defined in client
Write Point record to database defined in client
(write-points client points)Write collection of Point records to database defined in client
Write collection of Point records to database defined in client
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |